summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorXaviDCR92 <xavi.dcr@gmail.com>2018-07-09 23:20:46 +0200
committerXaviDCR92 <xavi.dcr@gmail.com>2018-07-09 23:20:46 +0200
commit188d74cb789f33967daf6daa5af17d41b6f59d4e (patch)
tree402953b5063497be39572093b7c5c4ec75b6136d
parent8ed9a3a57ad08bac4e8441b0b87ddc946296a3fd (diff)
downloadpocketempires-188d74cb789f33967daf6daa5af17d41b6f59d4e.tar.gz
Unit renamed to BaseUnit.
-rw-r--r--BaseUnit.cpp (renamed from Unit.cpp)6
-rw-r--r--BaseUnit.h36
-rw-r--r--Unit.h26
3 files changed, 39 insertions, 29 deletions
diff --git a/BaseUnit.h b/BaseUnit.h
new file mode 100644
index 0000000..485ac94
--- /dev/null
+++ b/BaseUnit.h
@@ -0,0 +1,36 @@
+#ifndef BASEUNIT_H__
+#define BASEUNIT_H__
+
+/* *******************************************************************
+ * Includes
+ * ******************************************************************/
+
+#include "BaseUnit.h"
+
+/* *******************************************************************
+ * Defines
+ * ******************************************************************/
+
+/* *******************************************************************
+ * Global types definition
+ * ******************************************************************/
+
+/* *******************************************************************
+ * Global variables declaration
+ * ******************************************************************/
+
+/* *******************************************************************
+ * Global functions declaration
+ * ******************************************************************/
+
+/* *******************************************************************
+ * Class definition
+ * ******************************************************************/
+
+class BaseUnit
+{
+ public:
+ explicit BaseUnit(void);
+};
+
+#endif /* BASEUNIT_H__ */
diff --git a/Unit.h b/Unit.h
deleted file mode 100644
index 1508a88..0000000
--- a/Unit.h
+++ /dev/null
@@ -1,26 +0,0 @@
-#ifndef UNIT_H__
-#define UNIT_H__
-
-/* *************************************
- * Includes
- * *************************************/
-
-/* *************************************
- * Defines
- * *************************************/
-
-/* *************************************
- * Structs and enums
- * *************************************/
-
-/* *************************************
- * Class definition
- * *************************************/
-
-class Unit
-{
- public:
- Unit(void);
-};
-
-#endif /* UNIT_H__ */
diff --git a/Unit.cpp b/BaseUnit.cpp
index ad49f2e..ff431b5 100644
--- a/Unit.cpp
+++ b/BaseUnit.cpp
@@ -2,7 +2,7 @@
* Includes
* ******************************************************************/
-#include "Unit.h"
+#include "BaseUnit.h"
/* *******************************************************************
* Defines
@@ -30,10 +30,10 @@
/*****************************************************************//**
*
* \brief Constructor for Unit class.
*
*********************************************************************/
-Unit::Unit(void)
+BaseUnit::BaseUnit(void)
{
}
@@ -30,10 +30,10 @@
/*****************************************************************//**
*
- * \brief Constructor for Unit class.
+ * \brief Constructor for BaseUnit class.
*
*********************************************************************/